summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorDiana Z <dzigterman@chromium.org>2021-08-14 22:58:16 -0600
committerCommit Bot <commit-bot@chromium.org>2021-09-16 17:14:04 +0000
commitabc6c7ad71d85532db725198cecab0aa282e7b50 (patch)
tree49b217857e2079e69a4a7f472eddb95a83adff19 /include
parent414feb169e244b2037e6a92a45500cc73faeea08 (diff)
downloadchrome-ec-abc6c7ad71d85532db725198cecab0aa282e7b50.tar.gz
USB MUX: Update mux HPD update interface to use mux_state_t
Since the drivers are now taking a mux_state_t set of flags to update, go ahead and unify the usb_mux API this way as well. It makes the parameters more apparent than the 1/0 inputs, and aligns the stack to use the same parameters. BRANCH=None BUG=b:172222942 TEST=make -j buildall Signed-off-by: Diana Z <dzigterman@chromium.org> Change-Id: Ie943dbdf03818d8497c0e328adf2b9794585d96e Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3095438 Commit-Queue: Abe Levkoy <alevkoy@chromium.org> Reviewed-by: Abe Levkoy <alevkoy@chromium.org>
Diffstat (limited to 'include')
-rw-r--r--include/usb_mux.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/include/usb_mux.h b/include/usb_mux.h
index c3f673b93a..9909f1c1c5 100644
--- a/include/usb_mux.h
+++ b/include/usb_mux.h
@@ -247,10 +247,9 @@ void usb_mux_flip(int port);
* Update the hot-plug event.
*
* @param port port number.
* @param hpd_lvl HPD level.
* @param hpd_irq HPD IRQ.
*/
-void usb_mux_hpd_update(int port, int hpd_lvl, int hpd_irq);
+void usb_mux_hpd_update(int port, mux_state_t mux_state);
/**
* Port information about retimer firmware update support.
@@ -247,10 +247,9 @@ void usb_mux_flip(int port);
*
* @param port port number.
- * @param hpd_lvl HPD level.
- * @param hpd_irq HPD IRQ.
+ * @param mux_state HPD IRQ and LVL mux flags
*/